% Auto-generated chapter 24 for tirmidhi
% Hadiths in this chapter: 68

\hadithdefcmd{tirmidhi}{1720}{حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ، عَنْ نَافِعٍ، عَنْ سَعِيدِ بْنِ أَبِي هِنْدٍ، عَنْ أَبِي مُوسَى الأَشْعَرِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ حُرِّمَ لِبَاسُ الْحَرِيرِ وَالذَّهَبِ عَلَى ذُكُورِ أُمَّتِي وَأُحِلَّ لإِنَاثِهِمْ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ عُمَرَ وَعَلِيٍّ وَعُقْبَةَ بْنِ عَامِرٍ وَأَنَسٍ وَحُذَيْفَةَ وَأُمِّ هَانِئٍ وَعَبْدِ اللَّهِ بْنِ عَمْرٍو وَعِمْرَانَ بْنِ حُصَيْنٍ وَعَبْدِ اللَّهِ بْنِ الزُّبَيْرِ وَجَابِرٍ وَأَبِي رَيْحَانَةَ وَابْنِ عُمَرَ وَوَاثِلَةَ بْنِ الأَسْقَعِ ‏.‏ وَحَدِيثُ أَبِي مُوسَى حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1720}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Abu Musa Al-Ash'ari: That the Messenger of Allah (ﷺ) said: "Wearing silk and gold has made unlawful for the males of my Ummah and lawful for its females. [Abu 'Eisa said:] There are narrations on this topic from 'Umar, 'Ali, 'Uqbah bin 'Amir, Anas, Umm Hani, Hudhaifah, 'Abdullah bin 'Amr, 'Imran bin Husain, 'Abdullah bin Az-Zubair, Jabir, Abu Raihanah, Ibn 'Umar, Al-Bara', and Wathilah bin Al-Asqa', and this Hadith is Hasan Sahih}}
\hadithdefcmd{tirmidhi}{1721}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، حَدَّثَنَا أَبِي، عَنْ قَتَادَةَ، عَنِ الشَّعْبِيِّ، عَنْ سُوَيْدِ بْنِ غَفَلَةَ، عَنْ عُمَرَ، أَنَّهُ خَطَبَ بِالْجَابِيَةِ فَقَالَ نَهَى نَبِيُّ اللَّهِ صلى الله عليه وسلم عَنِ الْحَرِيرِ إِلاَّ مَوْضِعَ أُصْبُعَيْنِ أَوْ ثَلاَثٍ أَوْ أَرْبَعٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1721}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated Suwaid bin Ghafalah: That 'Umar gave a Khutbah at Al-Jabiyah and he said: "The Messenger of Allah (ﷺ) prohibited silk except for two finger's worth of space, or three, or four." [Abu 'Eisa said:] This Hadith is Hasan Sahih}}
\hadithdefcmd{tirmidhi}{1722}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا عَبْدُ الصَّمَدِ بْنُ عَبْدِ الْوَارِثِ، حَدَّثَنَا هَمَّامٌ، حَدَّثَنَا قَتَادَةُ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ عَبْدَ الرَّحْمَنِ بْنَ عَوْفٍ، وَالزُّبَيْرَ بْنَ الْعَوَّامِ، شَكَيَا الْقَمْلَ إِلَى النَّبِيِّ صلى الله عليه وسلم فِي غَزَاةٍ لَهُمَا فَرَخَّصَ لَهُمَا فِي قُمُصِ الْحَرِيرِ قَالَ وَرَأَيْتُهُ عَلَيْهِمَا ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1722}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Anas bin Malik: That 'Abdur Rahman bin 'Awf and Az-Zubair bin Al-'Awwam complained of lice to the Prophet (ﷺ) during a battle that they participated in. So he permitted them to wear silk shirts. He (Anas) said: "I saw them wearing them." [Abu 'Eisa said:] This Hadith is Hasan Sahih}}
\hadithdefcmd{tirmidhi}{1723}{حَدَّثَنَا أَبُو عَمَّارٍ، حَدَّثَنَا الْفَضْلُ بْنُ مُوسَى، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، حَدَّثَنَا وَاقِدُ بْنُ عَمْرِو بْنِ سَعْدِ بْنِ مُعَاذٍ، قَالَ قَدِمَ أَنَسُ بْنُ مَالِكٍ فَأَتَيْتُهُ فَقَالَ مَنْ أَنْتَ فَقُلْتُ أَنَا وَاقِدُ بْنُ عَمْرِو بْنِ سَعْدِ بْنِ مُعَاذٍ، ‏.‏ قَالَ فَبَكَى وَقَالَ إِنَّكَ لَشَبِيهٌ بِسَعْدٍ وَإِنَّ سَعْدًا كَانَ مِنْ أَعْظَمِ النَّاسِ وَأَطْوَلِهِمْ وَإِنَّهُ بَعَثَ إِلَى النَّبِيِّ صلى الله عليه وسلم جُبَّةً مِنْ دِيبَاجٍ مَنْسُوجٌ فِيهَا الذَّهَبُ فَلَبِسَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَصَعِدَ الْمِنْبَرَ فَقَامَ أَوْ قَعَدَ فَجَعَلَ النَّاسُ يَلْمُسُونَهَا فَقَالُوا مَا رَأَيْنَا كَالْيَوْمِ ثَوْبًا قَطُّ ‏.‏ فَقَالَ ‏ "‏ أَتَعْجَبُونَ مِنْ هَذِهِ لَمَنَادِيلُ سَعْدٍ فِي الْجَنَّةِ خَيْرٌ مِمَّا تَرَوْنَ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَسْمَاءَ بِنْتِ أَبِي بَكْرٍ ‏.‏ وَهَذَا حَدِيثٌ صَحِيحٌ ‏.‏\hadithno{1723}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Waqid bin 'Amr bin Sa'd bin Mu'adh: "Anas bin Malik arrived. So I went to him and he said: 'Who are you ?' I said: 'I am Waqid bin 'Amr [bin Sa'd bin Ma'adh].'" He said: "So he began to cry and he said: 'You resemble Sa'd. Sa'd was one of the greatest people, and of the tallest. The Messenger of Allah (ﷺ) was sent a cloak of Dibaj with gold woven into it. The Messenger of Allah (ﷺ) wore it and ascended the Minbar. Then he stood, or sat, and the people began touching it, and they said: 'We never saw a garment like this before today.' So he said: 'Are you amazed at this ? The handkerchiefs of Sa'd in Paradise are better than what you see.'" He said: There is something on this topic from Asma' bint Abu Bakr. This Hadith is Sahih}}
\hadithdefcmd{tirmidhi}{1724}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْبَرَاءِ، قَالَ مَا رَأَيْتُ مِنْ ذِي لِمَّةٍ فِي حُلَّةٍ حَمْرَاءَ أَحْسَنَ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم لَهُ شَعْرٌ يَضْرِبُ مَنْكِبَيْهِ بَعِيدُ مَا بَيْنَ الْمَنْكِبَيْنِ لَمْ يَكُنْ بِالْقَصِيرِ وَلاَ بِالطَّوِيلِ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ جَابِرِ بْنِ سَمُرَةَ وَأَبِي رِمْثَةَ وَأَبِي جُحَيْفَةَ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1724}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Al-Bara' : "I have not seen anyone with hair past his shoulders in a red Hullah more handsome than the Messenger of Allah (ﷺ). He had hair that would flow on his shoulders, (and he had) broad shoulders (and he was) not too short and not too long." [Abu 'Eisa said:] There are narrations on this topic from Jabir bin Samurah, Abu Rimthah, and Abu Juhaifah. This Hadith is Hasan Sahih}}
\hadithdefcmd{tirmidhi}{1725}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا مَالِكُ بْنُ أَنَسٍ، عَنْ نَافِعٍ، عَنْ إِبْرَاهِيمَ بْنِ عَبْدِ اللَّهِ بْنِ حُنَيْنٍ، عَنْ أَبِيهِ، عَنْ عَلِيٍّ، قَالَ نَهَانِي النَّبِيُّ صلى الله عليه وسلم عَنْ لُبْسِ الْقَسِّيِّ وَالْمُعَصْفَرِ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ أَنَسٍ وَعَبْدِ اللَّهِ بْنِ عَمْرٍو وَحَدِيثُ عَلِيٍّ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1725}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated 'Ali: "The Messenger of Allah (ﷺ) prohibited wearing Al-Qassi and what was dyed with 'Usfur." [Abu 'Eisa said:] There are narrations on this topic from Anas and 'Abdullah bin 'Amr}}
\hadithdefcmd{tirmidhi}{1726}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ مُوسَى الْفَزَارِيُّ، حَدَّثَنَا سَيْفُ بْنُ هَارُونَ الْبُرْجُمِيُّ، عَنْ سُلَيْمَانَ التَّيْمِيِّ، عَنْ أَبِي عُثْمَانَ، عَنْ سَلْمَانَ، قَالَ سُئِلَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ السَّمْنِ وَالْجُبْنِ وَالْفِرَاءِ ‏.‏ فَقَالَ ‏ "‏ الْحَلاَلُ مَا أَحَلَّ اللَّهُ فِي كِتَابِهِ وَالْحَرَامُ مَا حَرَّمَ اللَّهُ فِي كِتَابِهِ وَمَا سَكَتَ عَنْهُ فَهُوَ مِمَّا عَفَا عَنْهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنِ الْمُغِيرَةِ ‏.‏ وَهَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ مَرْفُوعًا إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏ وَرَوَى سُفْيَانُ وَغَيْرُهُ عَنْ سُلَيْمَانَ التَّيْمِيِّ عَنْ أَبِي عُثْمَانَ عَنْ سَلْمَانَ قَوْلَهُ وَكَأَنَّ الْحَدِيثَ الْمَوْقُوفَ أَصَحُّ ‏.‏ وَسَأَلْتُ الْبُخَارِيَّ عَنْ هَذَا الْحَدِيثِ فَقَالَ مَا أُرَاهُ مَحْفُوظًا رَوَى سُفْيَانُ عَنْ سُلَيْمَانَ التَّيْمِيِّ عَنْ أَبِي عُثْمَانَ عَنْ سَلْمَانَ مَوْقُوفًا ‏.‏ قَالَ الْبُخَارِيُّ وَسَيْفُ بْنُ هَارُونَ مُقَارِبُ الْحَدِيثِ وَسَيْفُ بْنُ مُحَمَّدٍ عَنْ عَاصِمٍ ذَاهِبُ الْحَدِيثِ ‏.‏\hadithno{1726}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Narrated Salman: "The Messenger of Allah (ﷺ) was asked about fat, cheese, and furs, so he said: 'The lawful is what Allah made lawful in His Book, the unlawful is what Allah made unlawful in his Book, and what He was silent about; then it is among that for which He has pardoned.'" [Abu 'Eisa said:] There is something on this topic from Al-Mughirah, and this Hadith is Gharib, we do not know of it being Marfu' except from this route. Sufyan and others reported it from Sulaiman At-Taimi, from Abu 'Uthman, from Salman as his own saying. It is as if the Mawquf narration is more correct. I asked Al-Bukhari about this Hadith and he said: 'I do not think it is preserved. Sufyan reported it from Sulaiman At-Taimi from Abu 'Uthman, from Salman in Mawquf form.' Al-Bukhari said: "Saif bin Harun is Muqarib (Average) in Hadith, and as for Saif bin Muhammad from 'Asim, his narrations are left}}
\hadithdefcmd{tirmidhi}{1727}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ عَطَاءِ بْنِ أَبِي رَبَاحٍ، قَالَ سَمِعْتُ ابْنَ عَبَّاسٍ، يَقُولُ مَاتَتْ شَاةٌ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لأَهْلِهَا ‏ "‏ أَلاَ نَزَعْتُمْ جِلْدَهَا ثُمَّ دَبَغْتُمُوهُ فَاسْتَمْتَعْتُمْ بِهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ سَلَمَةَ بْنِ الْمُحَبِّقِ وَمَيْمُونَةَ وَعَائِشَةَ ‏.‏ وَحَدِيثُ ابْنِ عَبَّاسٍ حَسَنٌ صَحِيحٌ وَقَدْ رُوِيَ مِنْ غَيْرِ وَجْهٍ عَنِ ابْنِ عَبَّاسٍ عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوُ هَذَا ‏.‏ وَرُوِيَ عَنِ ابْنِ عَبَّاسٍ عَنْ مَيْمُونَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَرُوِيَ عَنْهُ عَنْ سَوْدَةَ وَسَمِعْتُ مُحَمَّدًا يُصَحِّحُ حَدِيثَ ابْنِ عَبَّاسٍ عَنِ النَّبِيِّ صلى الله عليه وسلم وَحَدِيثَ ابْنِ عَبَّاسٍ عَنْ مَيْمُونَةَ وَقَالَ احْتَمَلَ أَنْ يَكُونَ رَوَى ابْنُ عَبَّاسٍ عَنْ مَيْمُونَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم وَرَوَى ابْنُ عَبَّاسٍ عَنِ النَّبِيِّ صلى الله عليه وسلم وَلَمْ يَذْكُرْ فِيهِ عَنْ مَيْمُونَةَ ‏.‏ قَالَ أَبُو عِيسَى وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَكْثَرِ أَهْلِ الْعِلْمِ وَهُوَ قَوْلُ سُفْيَانَ الثَّوْرِيِّ وَابْنِ الْمُبَارَكِ وَالشَّافِعِيِّ وَأَحْمَدَ وَإِسْحَاقَ ‏.‏\hadithno{1727}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Ibn 'Abbas: "A sheep died so the Messenger of Allah (ﷺ) said to its owners: 'Why dont you remove its skin, then tan it so you can have something useful from it." [Abu 'Eisa said:] There are narrations on this topic from Salamah bin Al-Muhabbaq, Maimunah, and 'Aishah. The Hadith of Ibn 'Abbas is Hasan Sahih. Similar to this has been reported through other routes from Ibn 'Abbas from the Prophet (ﷺ). And it has been related from Ibn 'Abbas from Maimunah, from the Prophet (ﷺ), and, it has been related from him from Sawdah. I heard Muhammad saying the Hadith of Ibn 'Abbas from Maimunah from the Prophet (ﷺ) were correct. And he said: "It implies that it was reported from Ibn 'Abbas from Maimunah from the Prophet (ﷺ), and that Ibn 'Abbas reported it from the Prophet (ﷺ), and he did not mention Maimunah in it." [Abu 'Eisa said:] This is acted upon according to most of the people of knowledge, and it is the view of Sufyan At-Thawri, Ibn Al-Mubarak, Ash-Shafi'i, Ahmad, and Ishaq}}
\hadithdefcmd{tirmidhi}{1728}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، وَعَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ وَعْلَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَيُّمَا إِهَابٍ دُبِغَ فَقَدْ طَهُرَ ‏"‏ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَكْثَرِ أَهْلِ الْعِلْمِ قَالُوا فِي جُلُودِ الْمَيْتَةِ إِذَا دُبِغَتْ فَقَدْ طَهُرَتْ ‏.‏ قَالَ أَبُو عِيسَى قَالَ الشَّافِعِيُّ أَيُّمَا إِهَابِ مَيْتَةٍ دُبِغَ فَقَدْ طَهُرَ إِلاَّ الْكَلْبَ وَالْخِنْزِيرَ ‏.‏ وَاحْتَجَّ بِهَذَا الْحَدِيثِ ‏.‏ وَقَالَ بَعْضُ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ إِنَّهُمْ كَرِهُوا جُلُودَ السِّبَاعِ وَإِنْ دُبِغَ وَهُوَ قَوْلُ عَبْدِ اللَّهِ بْنِ الْمُبَارَكِ وَأَحْمَدَ وَإِسْحَاقَ وَشَدَّدُوا فِي لُبْسِهَا وَالصَّلاَةِ فِيهَا ‏.‏ قَالَ إِسْحَاقُ بْنُ إِبْرَاهِيمَ إِنَّمَا مَعْنَى قَوْلِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏"‏ أَيُّمَا إِهَابٍ دُبِغَ فَقَدْ طَهُرَ ‏"‏ ‏.‏ جِلْدُ مَا يُؤْكَلُ لَحْمُهُ هَكَذَا فَسَّرَهُ النَّضْرُ بْنُ شُمَيْلٍ ‏.‏ وَقَالَ إِسْحَاقُ قَالَ النَّضْرُ بْنُ شُمَيْلٍ إِنَّمَا يُقَالُ الإِهَابُ لِجِلْدِ مَا يُؤْكَلُ لَحْمُهُ ‏.‏\hadithno{1728}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated Ibn 'Abbas: That the Messenger of Allah (ﷺ) said: "Any skin tanned, then it has been made pure." This Hadith is Hasan Sahih. This is acted upon according to most of the people of knowledge, they say that when the skin of a dead animal has been tanned then it has been made pure. [Abu 'Eisa said:] Ash-Shafi'i said: "Any dead animals skin that is tanned, then it has been made pure, except for the dog and the pig." Some of the people of knowledge among the Companions of the Prophet (ﷺ) disliked skins of predators even when tanned, and this is the view of 'Abdullah bin Al-Mubarak, Ahmad and Ishaq, and they were firm about not wearing them and performing Salat in them. Ishaq bin Ibrahim said: "The saying of the Prophet (ﷺ):'Any skin that is tanned, then it has been made pure' only refers to the skins of animals whose meat is eaten." This is how it was explained by An-Nasr bin Shumail}}
\hadithdefcmd{tirmidhi}{1729}{حَدَّثَنَا مُحَمَّدُ بْنُ طَرِيفٍ الْكُوفِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، عَنِ الأَعْمَشِ، وَالشَّيْبَانِيِّ، عَنِ الْحَكَمِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، عَنْ عَبْدِ اللَّهِ بْنِ عُكَيْمٍ، قَالَ أَتَانَا كِتَابُ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَنْ لاَ تَنْتَفِعُوا مِنَ الْمَيْتَةِ بِإِهَابٍ وَلاَ عَصَبٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏ وَيُرْوَى عَنْ عَبْدِ اللَّهِ بْنِ عُكَيْمٍ عَنْ أَشْيَاخٍ لَهُمْ هَذَا الْحَدِيثُ ‏.‏ وَلَيْسَ الْعَمَلُ عَلَى هَذَا عِنْدَ أَكْثَرِ أَهْلِ الْعِلْمِ ‏.‏ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ عَنْ عَبْدِ اللَّهِ بْنِ عُكَيْمٍ أَنَّهُ قَالَ أَتَانَا كِتَابُ النَّبِيِّ صلى الله عليه وسلم قَبْلَ وَفَاتِهِ بِشَهْرَيْنِ ‏.‏ قَالَ وَسَمِعْتُ أَحْمَدَ بْنَ الْحَسَنِ يَقُولُ كَانَ أَحْمَدُ بْنُ حَنْبَلٍ يَذْهَبُ إِلَى هَذَا الْحَدِيثِ لِمَا ذُكِرَ فِيهِ قَبْلَ وَفَاتِهِ بِشَهْرَيْنِ وَكَانَ يَقُولُ كَانَ هَذَا آخِرَ أَمْرِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ ثُمَّ تَرَكَ أَحْمَدُ بْنُ حَنْبَلٍ هَذَا الْحَدِيثَ لَمَّا اضْطَرَبُوا فِي إِسْنَادِهِ حَيْثُ رَوَى بَعْضُهُمْ فَقَالَ عَنْ عَبْدِ اللَّهِ بْنِ عُكَيْمٍ عَنْ أَشْيَاخٍ لَهُمْ مِنْ جُهَيْنَةَ ‏.‏\hadithno{1729}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated 'Abdullah bin 'Ukaim: "A letter came from the Messenger of Allah (ﷺ) saying: 'Do not use the skins of dead animals, nor tendons.'" [Abu 'Eisa said:] This Hadith is Hasan. This Hadith has been related to 'Abdullah bin 'Ukaim from some Shuyukh of his, and this is not acted upon according to most of the people of knowledge. And this Hadith has been related from 'Abdullah bin 'Ukaim, that he said: "A letter came to us from the Messenger of Allah (ﷺ) two months before he died." He said: I heart Ahmad bin Al-Hasan saying: "Ahmad bin Hanbal followed this Hadith due to it mentioning that it was two months before he (ﷺ) died. Then Ahmad left this Hadith because of their Idtirab in its chain, since some of them reported it, saying: 'From 'Abdullah bin 'Ukaim from some Shuyukh of his from Juhainah}}
\hadithdefcmd{tirmidhi}{1730}{حَدَّثَنَا الأَنْصَارِيُّ، حَدَّثَنَا مَعْنٌ، حَدَّثَنَا مَالِكٌ، ح وَحَدَّثَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ نَافِعٍ، وَعَبْدِ اللَّهِ بْنِ دِينَارٍ، وَزَيْدِ بْنِ أَسْلَمَ، كُلُّهُمْ يُخْبِرُ عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَنْظُرُ اللَّهُ يَوْمَ الْقِيَامَةِ إِلَى مَنْ جَرَّ ثَوْبَهُ خُيَلاَءَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ حُذَيْفَةَ وَأَبِي سَعِيدٍ وَأَبِي هُرَيْرَةَ وَسَمُرَةَ وَأَبِي ذَرٍّ وَعَائِشَةَ وَهُبَيْبِ بْنِ مُغْفِلٍ ‏.‏ وَحَدِيثُ ابْنِ عُمَرَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1730}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated 'Abdullah bin 'Umar: That the Messenger of Allah (ﷺ) said: "On the day of judgement, Allah will not look at one who arrogantly drags his garment. [Abu 'Eisa said:] There are narrations on this topic from Hudhaifah, Abu Sa'eed, Abu Hurairah, Samurah, Abu Dharr, 'Aishah and Hubaib bin Mughfil. The Hadith of Ibn 'Umar is Hasan Sahih}}
\hadithdefcmd{tirmidhi}{1731}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ الْخَلاَّلُ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ جَرَّ ثَوْبَهُ خُيَلاَءَ لَمْ يَنْظُرِ اللَّهُ إِلَيْهِ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏ فَقَالَتْ أُمُّ سَلَمَةَ فَكَيْفَ يَصْنَعْنَ النِّسَاءُ بِذُيُولِهِنَّ قَالَ ‏"‏ يُرْخِينَ شِبْرًا ‏"‏ ‏.‏ فَقَالَتْ إِذًا تَنْكَشِفَ أَقْدَامُهُنَّ ‏.‏ قَالَ ‏"‏ فَيُرْخِينَهُ ذِرَاعًا لاَ يَزِدْنَ عَلَيْهِ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1731}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Ibn 'Umar: That the Messenger of Allah (ﷺ) said: "Whoever arrogantly drags his garment, Allah will not look at him on the Day of Judgement." So Umm Salamah said: "What should the women do with their hems?" He said: "Slacken them a handspan." So she said: "Then their feet will be uncovered." He said: "Then slacken them a forearm's length and do not add to that." He said: This Hadith is Hasan Sahih. In the Hadith there is a concession for women to drag their Izar because it covers them better}}
\hadithdefcmd{tirmidhi}{1732}{حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، أَخْبَرَنَا عَفَّانُ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ عَلِيِّ بْنِ زَيْدٍ، عَنْ أُمِّ الْحَسَنِ الْبَصْرِيِّ، أَنَّ أُمَّ سَلَمَةَ، حَدَّثَتْهُمْ أَنَّ النَّبِيَّ صلى الله عليه وسلم شَبَّرَ لِفَاطِمَةَ شِبْرًا مِنْ نِطَاقِهَا ‏.‏ قَالَ أَبُو عِيسَى وَرَوَى بَعْضُهُمْ عَنْ حَمَّادِ بْنِ سَلَمَةَ عَنْ عَلِيِّ بْنِ زَيْدٍ عَنِ الْحَسَنِ عَنْ أُمِّهِ عَنْ أُمِّ سَلَمَةَ ‏.‏ وَفِي هَذَا الْحَدِيثِ رُخْصَةٌ لِلنِّسَاءِ فِي جَرِّ الإِزَارِ لأَنَّهُ يَكُونُ أَسْتَرَ لَهُنَّ ‏.‏\hadithno{1732}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Umm Salamah: "The Prophet (ﷺ) slackened Fatimah's garment a hand-span." [Abu 'Eisa said:] Some of them reported it from Hammad bin Salamah, from 'Ali bin Zaid, from Al-Hasan, from his father, from Umm Salamah}}
\hadithdefcmd{tirmidhi}{1733}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا أَيُّوبُ، عَنْ حُمَيْدِ بْنِ هِلاَلٍ، عَنْ أَبِي بُرْدَةَ، قَالَ أَخْرَجَتْ إِلَيْنَا عَائِشَةُ كِسَاءً مُلَبَّدًا وَإِزَارًا غَلِيظًا فَقَالَتْ قُبِضَ رُوحُ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي هَذَيْنِ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ عَلِيٍّ وَابْنِ مَسْعُودٍ ‏.‏ وَحَدِيثُ عَائِشَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1733}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Abu Burdah: "'Aishah brought a patched woolen Kisa' (cloak), and a thick Izar, She said: 'The Messenger of Allah (ﷺ) died in these.'" [Abu 'Eisa said:] There are narrations on this topic from 'Ali and Ibn Mas'ud. The Hadith if 'Aishah is Hasan Sahih Hadith}}
\hadithdefcmd{tirmidhi}{1734}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، حَدَّثَنَا خَلَفُ بْنُ خَلِيفَةَ، عَنْ حُمَيْدٍ الأَعْرَجِ، عَنْ عَبْدِ اللَّهِ بْنِ الْحَارِثِ، عَنِ ابْنِ مَسْعُودٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ كَانَ عَلَى مُوسَى يَوْمَ كَلَّمَهُ رَبُّهُ كِسَاءُ صُوفٍ وَجُبَّةُ صُوفٍ وَكُمَّةُ صُوفٍ وَسَرَاوِيلُ صُوفٍ وَكَانَتْ نَعْلاَهُ مِنْ جِلْدِ حِمَارٍ مَيِّتٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ حُمَيْدٍ الأَعْرَجِ ‏.‏ وَحُمَيْدٌ هُوَ ابْنُ عَلِيٍّ الْكُوفِيُّ ‏.‏ قَالَ سَمِعْتُ مُحَمَّدًا يَقُولُ حُمَيْدُ بْنُ عَلِيٍّ الأَعْرَجُ مُنْكَرُ الْحَدِيثِ وَحُمَيْدُ بْنُ قَيْسٍ الأَعْرَجُ الْمَكِّيُّ صَاحِبُ مُجَاهِدٍ ثِقَةٌ ‏.‏ وَالْكُمَّةُ الْقَلَنْسُوَةُ الصَّغِيرَةُ ‏.‏\hadithno{1734}\hadithgrade{Ahmad Muhammad Shakir: Very Daif; Al-Albani: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ibn Mas'ud: That the Prophet (ﷺ) said: "On the day of His Lord spoke to him, Musa was wearing a wool Kisa', a wool Jubbah, a wool Kummah, wool pants, and his sandals were made of the skin of a dead donkey." [Abu 'Eisa said:] This Hadith is Gharib, we do not know of it except from the the narration of Humaid Al-A'raj. And Humaid - Ibn 'Ali Al-A'raj - I Heard Muhammad saying: "Humaid bin 'Ali Al-A'raj is Munkar in Hadith." While Humaid ibn Qais Al-A'raj Al-Makki, the companion of Mujahid is trustworthy. The Kummah is a small cap}}
\hadithdefcmd{tirmidhi}{1735}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، عَنْ حَمَّادِ بْنِ سَلَمَةَ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ دَخَلَ النَّبِيُّ صلى الله عليه وسلم مَكَّةَ يَوْمَ الْفَتْحِ وَعَلَيْهِ عِمَامَةٌ سَوْدَاءُ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَلِيٍّ وَعَمْرِو بْنِ حُرَيْثٍ وَابْنِ عَبَّاسٍ وَرُكَانَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ جَابِرٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1735}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Jabir: "On the day of the Conquest, the Prophet (ﷺ) entered Makkah, and he was wearing a black 'Imamah." [He said:] THere are narrations on this topic from 'Ali, 'Amr bin Huraith, Ibn 'Abbas, Rukanah. [Abu 'Eisa said:] The Hadith is Jabir is Hasan Sahih Hadith}}
\hadithdefcmd{tirmidhi}{1736}{حَدَّثَنَا هَارُونُ بْنُ إِسْحَاقَ الْهَمْدَانِيُّ، حَدَّثَنَا يَحْيَى بْنُ مُحَمَّدٍ الْمَدَنِيُّ، عَنْ عَبْدِ الْعَزِيزِ بْنِ مُحَمَّدٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم إِذَا اعْتَمَّ سَدَلَ عِمَامَتَهُ بَيْنَ كَتِفَيْهِ ‏.‏ قَالَ نَافِعٌ وَكَانَ ابْنُ عُمَرَ يَسْدِلُ عِمَامَتَهُ بَيْنَ كَتِفَيْهِ ‏.‏ قَالَ عُبَيْدُ اللَّهِ وَرَأَيْتُ الْقَاسِمَ وَسَالِمًا يَفْعَلاَنِ ذَلِكَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ وَفِي الْبَابِ عَنْ عَلِيٍّ وَلاَ يَصِحُّ حَدِيثُ عَلِيٍّ فِي هَذَا مِنْ قِبَلِ إِسْنَادِهِ ‏\hadithno{1736}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Nafi': That Ibn 'Umar said: "When the Messenger of Allah (ﷺ) would wear an 'Imamah would hang between his shoulders." Nafi' said: "Ibn 'Umar would hang his 'Imamah between his shoulders." 'Ubaidullah said: "And I saw Al-Qasim and Salim doing that." [Abu 'Eisa said:] This Hadith is Hasan Gharib. And there is something on this topic from 'Ali. And this Hadith of 'Ali about this is not correct due to its chain}}
\hadithdefcmd{tirmidhi}{1737}{حَدَّثَنَا سَلَمَةُ بْنُ شَبِيبٍ، وَالْحَسَنُ بْنُ عَلِيٍّ الْخَلاَّلُ، وَغَيْرُ، وَاحِدٍ، قَالُوا حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ إِبْرَاهِيمَ بْنِ عَبْدِ اللَّهِ بْنِ حُنَيْنٍ، عَنْ أَبِيهِ، عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، قَالَ نَهَانِي النَّبِيُّ صلى الله عليه وسلم عَنِ التَّخَتُّمِ بِالذَّهَبِ وَعَنْ لِبَاسِ الْقَسِّيِّ وَعَنِ الْقِرَاءَةِ فِي الرُّكُوعِ وَالسُّجُودِ وَعَنْ لِبَاسِ الْمُعَصْفَرِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1737}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated 'Ali bin Abi Talib: "The Messenger of Allah (ﷺ) prohibited me from rings of gold, and from wearing Al-Qassi, and from reciting in the bowing and prostration positions, and from wearing what was dyed with 'Usfur." [Abu 'Eisa said:] This Hadith is Hasan Sahih}}
\hadithdefcmd{tirmidhi}{1738}{حَدَّثَنَا يُوسُفُ بْنُ حَمَّادٍ الْمَعْنِيُّ الْبَصْرِيُّ، حَدَّثَنَا عَبْدُ الْوَارِثِ بْنُ سَعِيدٍ، عَنْ أَبِي التَّيَّاحِ، حَدَّثَنَا حَفْصٌ اللَّيْثِيُّ، قَالَ أَشْهَدُ عَلَى عِمْرَانَ بْنِ حُصَيْنٍ أَنَّهُ حَدَّثَنَا أَنَّهُ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ التَّخَتُّمِ بِالذَّهَبِ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَلِيٍّ وَابْنِ عُمَرَ وَأَبِي هُرَيْرَةَ وَمُعَاوِيَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عِمْرَانَ حَدِيثٌ حَسَنٌ ‏.‏ وَأَبُو التَّيَّاحِ اسْمُهُ يَزِيدُ بْنُ حُمَيْدٍ ‏.‏\hadithno{1738}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated 'Imran bin Husain: "The Messenger of Allah (ﷺ) prohibited us from (wearing) rings of gold." [He said:] THere are narrations on this topic from 'Ali, Ibn 'Umar, Abu Hurairah, and Mu'awiyah. [Abu 'Eisa said:] The Hadith of 'Imran is a Hasan Hadith. Abu At-Tayyah's (a narrator) name is Yazid bin Humaid}}
\hadithdefcmd{tirmidhi}{1739}{حَدَّثَنَا قُتَيْبَةُ، وَغَيْرُ، وَاحِدٍ، عَنْ عَبْدِ اللَّهِ بْنِ وَهْبٍ، عَنْ يُونُسَ، عَنِ ابْنِ شِهَابٍ، عَنْ أَنَسٍ، قَالَ كَانَ خَاتَمُ النَّبِيِّ صلى الله عليه وسلم مِنْ وَرِقٍ وَكَانَ فَصُّهُ حَبَشِيًّا ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ عُمَرَ وَبُرَيْدَةَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{1739}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Anas: "The Prophet (ﷺ) had ring made of silver and its stone (Fass) was Ethiopian." He said: There are narrations on this topic from Ibn 'Umar and Buraidah. [Abu 'Eisa said:] This Hadith is Hasan Sahih Gharib from this route}}
\hadithdefcmd{tirmidhi}{1740}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا حَفْصُ بْنُ عُمَرَ بْنِ عُبَيْدٍ الطَّنَافِسِيُّ، حَدَّثَنَا زُهَيْرُ بْنُ مُعَاوِيَةَ أَبُو خَيْثَمَةَ، عَنْ حُمَيْدٍ، عَنْ أَنَسٍ، قَالَ كَانَ خَاتَمُ رَسُولِ اللَّهِ صلى الله عليه وسلم مِنْ فِضَّةٍ فَصُّهُ مِنْهُ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{1740}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Anas: "The ring of the Messenger of Allah (ﷺ) was made of silver, its Fass was from it." [Abu 'Eisa said:] This Hadith is Hasan Sahih Gharib from this route}}
\hadithdefcmd{tirmidhi}{1741}{حَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدٍ الْمُحَارِبِيُّ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ أَبِي حَازِمٍ، عَنْ مُوسَى بْنِ عُقْبَةَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم صَنَعَ خَاتَمًا مِنْ ذَهَبٍ فَتَخَتَّمَ بِهِ فِي يَمِينِهِ ثُمَّ جَلَسَ عَلَى الْمِنْبَرِ فَقَالَ ‏ "‏ إِنِّي كُنْتُ اتَّخَذْتُ هَذَا الْخَاتَمَ فِي يَمِينِي ‏"‏ ‏.‏ ثُمَّ نَبَذَهُ وَنَبَذَ النَّاسُ خَوَاتِيمَهُمْ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَلِيٍّ وَجَابِرٍ وَعَبْدِ اللَّهِ بْنِ جَعْفَرٍ وَابْنِ عَبَّاسٍ وَعَائِشَةَ وَأَنَسٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عُمَرَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ عَنْ نَافِعٍ عَنِ ابْنِ عُمَرَ نَحْوَ هَذَا مِنْ غَيْرِ هَذَا الْوَجْهِ وَلَمْ يَذْكُرْ فِيهِ أَنَّهُ تَخَتَّمَ فِي يَمِينِهِ ‏.‏\hadithno{1741}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated Ibn 'Umar: "The Prophet (ﷺ) had a ring of gold made for him which he wore on his right (hand). Then he sat on the Minbar and said: 'I did indeed have this ring on my right hand' then he discarded it and the people discarded their rings." He said: There are narrations on this topic from 'Ali, Jabir, 'Abdullah bin Ja'far, Ibn 'Abbas, 'Aishah, and Anas. [Abu 'Eisa said:] The Hadith of Ibn 'Umar is Hasan Sahih Hadith. This Hadith has been reported similarly from 'Nafi, from Ibn 'Umar, through routes other than this, and it was not mentioned in it that the ring was on his right hand}}
\hadithdefcmd{tirmidhi}{1742}{حَدَّثَنَا مُحَمَّدُ بْنُ حُمَيْدٍ الرَّازِيُّ، حَدَّثَنَا جَرِيرٌ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنِ الصَّلْتِ بْنِ عَبْدِ اللَّهِ بْنِ نَوْفَلٍ، قَالَ رَأَيْتُ ابْنَ عَبَّاسٍ يَتَخَتَّمُ فِي يَمِينِهِ وَلاَ إِخَالُهُ إِلاَّ قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَتَخَتَّمُ فِي يَمِينِهِ ‏.‏ قَالَ أَبُو عِيسَى قَالَ مُحَمَّدُ بْنُ إِسْمَاعِيلَ حَدِيثُ مُحَمَّدِ بْنِ إِسْحَاقَ عَنِ الصَّلْتِ بْنِ عَبْدِ اللَّهِ بْنِ نَوْفَلٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1742}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated As-Salt bin 'Abdullah bin Nawfal: "Ibn Abbas wore a ring on his right hand. And I do not doubt he said: 'I saw the Messenger of Allah (ﷺ) wearing a ring on his right hand.'" [Abu 'Eisa said:] Muhammad bin Isma'il said: "The Hadith is Muhammad bin Ishaq from As-Salt bin 'Abdullah bin Nawfal is a Hasan Sahih Hadith}}
\hadithdefcmd{tirmidhi}{1743}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا حَاتِمُ بْنُ إِسْمَاعِيلَ، عَنْ جَعْفَرِ بْنِ مُحَمَّدٍ، عَنْ أَبِيهِ، قَالَ كَانَ الْحَسَنُ وَالْحُسَيْنُ يَتَخَتَّمَانِ فِي يَسَارِهِمَا ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1743}\hadithgrade{Ahmad Muhammad Shakir: Sahih Muquf; Al-Albani: Sahih Muquf; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ja'far bin Muhammad : Narrated from his father who said: "Al-Hasan and Al-Husain wore their ring on their left hand." This Hadith is Hasan Sahih}}
\hadithdefcmd{tirmidhi}{1744}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، عَنْ حَمَّادِ بْنِ سَلَمَةَ، قَالَ رَأَيْتُ ابْنَ أَبِي رَافِعٍ يَتَخَتَّمُ فِي يَمِينِهِ فَسَأَلْتُهُ عَنْ ذَلِكَ، فَقَالَ رَأَيْتُ عَبْدَ اللَّهِ بْنَ جَعْفَرٍ يَتَخَتَّمُ فِي يَمِينِهِ ‏.‏ وَقَالَ عَبْدُ اللَّهِ بْنُ جَعْفَرٍ كَانَ النَّبِيُّ صلى الله عليه وسلم يَتَخَتَّمُ فِي يَمِينِهِ ‏.‏ قَالَ وَقَالَ مُحَمَّدُ بْنُ إِسْمَاعِيلَ هَذَا أَصَحُّ شَيْءٍ رُوِيَ فِي هَذَا الْبَابِ ‏.‏\hadithno{1744}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Hammad bin Salamah: "I saw Ibn Rafi' [and he is 'Ubaidullah bin Abi Rafi', the freed slave of the Messenger of Allah (ﷺ) - and Aslam was the name of Ibn Abi Rafi] wearing a ring on his right, so I asked him about that. He said, 'I saw 'Abdullah bin Ja'far wearing a ring on his right hand, and he ['Abdullah bin Ja'far] said: "The Messenger of Allah (ﷺ) wore a ring on his right hand." He said: Muhammad [bin Isma'il] said: "This is the most correct thing related from the Prophet (ﷺ) on this topic}}
\hadithdefcmd{tirmidhi}{1745}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ الْخَلاَّلُ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ ثَابِتٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم صَنَعَ خَاتَمًا مِنْ وَرِقٍ فَنَقَشَ فِيهِ مُحَمَّدٌ رَسُولُ اللَّهِ ثُمَّ قَالَ ‏"‏ لاَ تَنْقُشُوا عَلَيْهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ صَحِيحٌ حَسَنٌ ‏.‏ وَمَعْنَى قَوْلِهِ ‏"‏ لاَ تَنْقُشُوا عَلَيْهِ ‏"‏ ‏.‏ نَهَى أَنْ يَنْقُشَ أَحَدٌ عَلَى خَاتَمِهِ مُحَمَّدٌ رَسُولُ اللَّهِ ‏.‏\hadithno{1745}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Anas bin Malik: "The Messenger of Allah (ﷺ) had a ring made from silver, so he had 'Muhammad, the Messenger of Allah' engraved on it. Then he said: 'Do not engrave with it.' [Abu 'Eisa said:] This Hadith is Sahih Hasan. As for the meaning of his saying: "Do not engrave with it" - he was prohibiting that anyone have "Muhammad, Messenger of Allah" engraved on his ring}}
\hadithdefcmd{tirmidhi}{1746}{حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، أَخْبَرَنَا سَعِيدُ بْنُ عَامِرٍ، وَالْحَجَّاجُ بْنُ مِنْهَالٍ، قَالاَ حَدَّثَنَا هَمَّامٌ، عَنِ ابْنِ جُرَيْجٍ، عَنِ الزُّهْرِيِّ، عَنْ أَنَسٍ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا دَخَلَ الْخَلاَءَ نَزَعَ خَاتَمَهُ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ ‏.‏\hadithno{1746}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Anas: "When the Messenger of Allah (ﷺ) entered the area in which he would relieve himself, he would remove the ring." [Abu 'Eisa said:] This Hadith is Hasan Sahih Gharib Hadith}}
\hadithdefcmd{tirmidhi}{1747}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ الأَنْصَارِيُّ، حَدَّثَنَا أَبِي، عَنْ ثُمَامَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ كَانَ نَقْشُ خَاتَمِ النَّبِيِّ صلى الله عليه وسلم مُحَمَّدٌ سَطْرٌ وَرَسُولُ سَطْرٌ وَاللَّهِ سَطْرٌ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَنَسٍ حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ ‏.‏\hadithno{1747}\hadithgrade{Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Narrated Anas bin Malik:"The inscription on the ring of the Prophet (ﷺ) was in three lines: 'Muhammad' on a line, 'Messenger' on a line, and 'Allah' on a line}}
\hadithdefcmd{tirmidhi}{1748}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، وَمُحَمَّدُ بْنُ يَحْيَى، وَغَيْرُ، وَاحِدٍ، قَالُوا حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ الأَنْصَارِيُّ، حَدَّثَنِي أَبِي، عَنْ ثُمَامَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ كَانَ نَقْشُ خَاتَمِ النَّبِيِّ صلى الله عليه وسلم ثَلاَثَةَ أَسْطُرٍ مُحَمَّدٌ سَطْرٌ وَرَسُولُ سَطْرٌ وَاللَّهِ سَطْرٌ ‏.‏ وَلَمْ يَذْكُرْ مُحَمَّدُ بْنُ يَحْيَى فِي حَدِيثِهِ ثَلاَثَةَ أَسْطُرٍ ‏.‏ وَفِي الْبَابِ عَنِ ابْنِ عُمَرَ ‏.‏\hadithno{1748}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Anas bin Malik: "The inscription on the ring of the Prophet (ﷺ) was in three line: 'Muhammad' on a line, 'Messenger' on a line, 'Allah' on a line." And Muhammad bin Yahya (one of the two who narrated to him) did not say: "Three lines" in his narration. There are narrations on this topic from Ibn 'Umar. [Abu 'Eisa said:] This Hadith of Anas is a Hasan Sahih Gharib}}
\hadithdefcmd{tirmidhi}{1749}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا رَوْحُ بْنُ عُبَادَةَ، حَدَّثَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي أَبُو الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الصُّورَةِ فِي الْبَيْتِ وَنَهَى أَنْ يُصْنَعَ ذَلِكَ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَلِيٍّ وَأَبِي طَلْحَةَ وَعَائِشَةَ وَأَبِي هُرَيْرَةَ وَأَبِي أَيُّوبَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ جَابِرٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1749}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Jabir: "The Messenger of Allah (ﷺ) prohibited having images in the house, and he prohibited making them." He said: There are narrations on this topic from 'Ali, Abu Talhah, 'Aishah, Abu Hurairah, and Abu Ayyub. [Abu 'Eisa said:] The Hadith of Jabir is a Hasan Sahih Hadith}}
\hadithdefcmd{tirmidhi}{1750}{حَدَّثَنَا إِسْحَاقُ بْنُ مُوسَى الأَنْصَارِيُّ، حَدَّثَنَا مَعْنٌ، حَدَّثَنَا مَالِكٌ، عَنْ أَبِي النَّضْرِ، عَنْ عُبَيْدِ اللَّهِ بْنِ عُتْبَةَ، أَنَّهُ دَخَلَ عَلَى أَبِي طَلْحَةَ الأَنْصَارِيِّ يَعُودُهُ ‏.‏ قَالَ فَوَجَدْتُ عِنْدَهُ سَهْلَ بْنَ حُنَيْفٍ ‏.‏ قَالَ فَدَعَا أَبُو طَلْحَةَ إِنْسَانًا يَنْزِعُ نَمَطًا تَحْتَهُ فَقَالَ لَهُ سَهْلٌ لِمَ تَنْزِعُهُ فَقَالَ لأَنَّ فِيهِ تَصَاوِيرَ وَقَدْ قَالَ النَّبِيُّ صلى الله عليه وسلم مَا قَدْ عَلِمْتَ ‏.‏ قَالَ سَهْلٌ أَوَلَمْ يَقُلْ ‏ "‏ إِلاَّ مَا كَانَ رَقْمًا فِي ثَوْبٍ ‏"‏ فَقَالَ بَلَى وَلَكِنَّهُ أَطْيَبُ لِنَفْسِي ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1750}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abu An-Nadr: From 'Ubaidullah bin 'Abdullah bin 'Utbah, that he entered upon Abu Talhah Al-Ansari to pay him a visit (while he was ill), and he found Sahl bin Hunaif with him. He said: "Abu Talhah called for someone to remove a sheet that was under him. Sahl said to him: 'Why did you remove it?' He replied: 'Because it contains images on it, and the Prophet (ﷺ) said about them what you know.' Sahl said: 'Do he not say: Except for markings on a garment?' He said: 'Yes, but this is better to me.'" [Abu 'Eisa said:] This Hadith is Hasan Sahih}}
\hadithdefcmd{tirmidhi}{1751}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَيُّوبَ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ صَوَّرَ صُورَةً عَذَّبَهُ اللَّهُ حَتَّى يَنْفُخَ فِيهَا يَعْنِي الرُّوحَ وَلَيْسَ بِنَافِخٍ فِيهَا وَمَنِ اسْتَمَعَ إِلَى حَدِيثِ قَوْمٍ وَهُمْ يَفِرُّونَ بِهِ مِنْهُ صُبَّ فِي أُذُنِهِ الآنُكُ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ وَأَبِي هُرَيْرَةَ وَأَبِي جُحَيْفَةَ وَعَائِشَةَ وَابْنِ عُمَرَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عَبَّاسٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1751}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Narrated Ibn 'Abbas: That the Messenger of Allah (ﷺ) said: "Whoever fashions an image, he will be punished by Allah until he breathes into it - meaning the soul - and he cannot breath (a soul) into it. And whoever listens to a people's conversation, while they have gone away from him for it, then He will have lead poured into his ears on the Day of Judgement." He said: There are narrations on this topic from 'Abdullah bin Mas'ud, Abu Hurairah, Abu Juhaifah, 'Aishah, and Ibn 'Umar. [Abu 'Eisa said:] The Hadith of Ibn 'Abbas is a Hasan Sahih Hadith}}
\hadithdefcmd{tirmidhi}{1752}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ عُمَرَ بْنِ أَبِي سَلَمَةَ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ غَيِّرُوا الشَّيْبَ وَلاَ تَشَبَّهُوا بِالْيَهُودِ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ الزُّبَيْرِ وَابْنِ عَبَّاسٍ وَجَابِرٍ وَأَبِي ذَرٍّ وَأَنَسٍ وَأَبِي رِمْثَةَ وَالْجَهْدَمَةِ وَأَبِي الطُّفَيْلِ وَجَابِرِ بْنِ سَمُرَةَ وَأَبِي جُحَيْفَةَ وَابْنِ عُمَرَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ وَقَدْ رُوِيَ مِنْ غَيْرِ وَجْهٍ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{1752}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abu Hurairah: That the Messenger of Allah (ﷺ) said: "Change the gray, and do not resemble the Jews." He said: There are narration on this topic from Az-Zubair, Ibn 'Abbas, Jabir, Abu Dharr, Anas, Abu Rimthah, Al-Jahdamah, Abu At-Tufail, Jabir bin Samurah, Abu Juhaifah, and Ibn 'Umar. [Abu 'Eisa said:] The Hadith of Abu Hurairah is a Hasan Sahih Hadith, and it has been reported through other routes from Abu Hurairah from the Prophet (ﷺ)}}
\hadithdefcmd{tirmidhi}{1753}{حَدَّثَنَا سُوَيْدُ بْنُ نَصْرٍ، أَخْبَرَنَا ابْنُ الْمُبَارَكِ، عَنِ الأَجْلَحِ، عَنْ عَبْدِ اللَّهِ بْنِ بُرَيْدَةَ، عَنْ أَبِي الأَسْوَدِ، عَنْ أَبِي ذَرٍّ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ أَحْسَنَ مَا غُيِّرَ بِهِ الشَّيْبُ الْحِنَّاءُ وَالْكَتَمُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَأَبُو الأَسْوَدِ الدِّيلِيُّ اسْمُهُ ظَالِمُ بْنُ عَمْرِو بْنِ سُفْيَانَ ‏.‏\hadithno{1753}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Abu Dharr: That the Prophet (ﷺ) said: "Indeed the best of what the gray may be changed with is Henna' and Katam." [Abu 'Eisa said:] This Hadith is Hasan Sahih. Abu Al-Aswad Ad-Dili's (a narrator in this chain) name is Zalim bin 'Amr bin Sufyan}}
\hadithdefcmd{tirmidhi}{1754}{حَدَّثَنَا حُمَيْدُ بْنُ مَسْعَدَةَ، حَدَّثَنَا عَبْدُ الْوَهَّابِ الثَّقَفِيُّ، عَنْ حُمَيْدٍ، عَنْ أَنَسٍ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم رَبْعَةً لَيْسَ بِالطَّوِيلِ وَلاَ بِالْقَصِيرِ حَسَنَ الْجِسْمِ أَسْمَرَ اللَّوْنِ وَكَانَ شَعْرُهُ لَيْسَ بِجَعْدٍ وَلاَ سَبْطٍ إِذَا مَشَى يَتَكَفَّأُ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَائِشَةَ وَالْبَرَاءِ وَأَبِي هُرَيْرَةَ وَابْنِ عَبَّاسٍ وَأَبِي سَعِيدٍ وَجَابِرٍ وَوَائِلِ بْنِ حُجْرٍ وَأُمِّ هَانِئٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَنَسٍ حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ مِنْ حَدِيثِ حُمَيْدٍ ‏.‏\hadithno{1754}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Narrated Anas: "The Messenger of Allah (ﷺ) was of average height, neither tall nor very short, he had a good build, brown in complexion, his hair was neither curly nor straight, and when he walked he swayed slightly." He said: There are narration on this topic from 'Aishah, Al-Bara', Abu Hurairah, Ibn 'Abbas, Abu Sa'eed, Jabir, Wa'il bin Hujr, and Umm Hani'. [Abu 'Eisa said:] The Hadith of Anas is a Hasan Sahih Gharib Hadith from this route, as a narration of Humaid}}
\hadithdefcmd{tirmidhi}{1755}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ أَبِي الزِّنَادِ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ كُنْتُ أَغْتَسِلُ أَنَا وَرَسُولُ اللَّهِ، صلى الله عليه وسلم مِنْ إِنَاءٍ وَاحِدٍ وَكَانَ لَهُ شَعْرٌ فَوْقَ الْجُمَّةِ وَدُونَ الْوَفْرَةِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏ وَقَدْ رُوِيَ مِنْ غَيْرِ وَجْهٍ عَنْ عَائِشَةَ أَنَّهَا قَالَتْ كُنْتُ أَغْتَسِلُ أَنَا وَرَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ إِنَاءٍ وَاحِدٍ ‏.‏ وَلَمْ يَذْكُرُوا فِيهِ هَذَا الْحَرْفَ وَكَانَ لَهُ شَعْرٌ فَوْقَ الْجُمَّةِ وَدُونَ الْوَفْرَةِ ‏.‏ وَعَبْدُ الرَّحْمَنِ بْنُ أَبِي الزِّنَادِ ثِقَةٌ كَانَ مَالِكُ بْنُ أَنَسٍ يُوَثِّقُهُ وَيَأْمُرُ بِالْكِتَابَةِ عَنْهُ ‏.‏\hadithno{1755}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated 'Aishah: "I and the Messenger of Allah (ﷺ) would perform Ghusl using (water from) the same vessel. He had hair reaching above his shoulders and below his earlobes." This Hadith is Hasan Sahih Gharib. [Abu 'Eisa said:] It has been reported from other routes that 'Aishah said: "I and the Messenger of Allah (ﷺ) would perform Ghusl using (water from) the same vessel." And the following statement is not mentioned in it: "He had hair reaching above his shoulders [and below his earlobes'." It was only mentioned by 'Abdur-Rahman bin Abi Az-Zinad, and he is trustworthy, a Hafiz, and Malik bin Anas stated that he was trustworthy and ordered recording (Ahadith) from him}}
\hadithdefcmd{tirmidhi}{1756}{\hadithno{1756}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih}\hadithtrans{}}
\hadithdefcmd{tirmidhi}{1757}{\hadithno{1757}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih}\hadithtrans{}}
\hadithdefcmd{tirmidhi}{1758}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا يَعْقُوبُ بْنُ عَبْدِ الرَّحْمَنِ الإِسْكَنْدَرَانِيُّ، عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى عَنْ لُبْسَتَيْنِ الصَّمَّاءِ وَأَنْ يَحْتَبِيَ الرَّجُلُ بِثَوْبِهِ لَيْسَ عَلَى فَرْجِهِ مِنْهُ شَيْءٌ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ عَلِيٍّ وَابْنِ عُمَرَ وَعَائِشَةَ وَأَبِي سَعِيدٍ وَجَابِرٍ وَأَبِي أُمَامَةَ ‏.‏ وَحَدِيثُ أَبِي هُرَيْرَةَ حَسَنٌ صَحِيحٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ وَقَدْ رُوِيَ هَذَا مِنْ غَيْرِ وَجْهٍ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{1758}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abu Hurairah: "The Messenger of Allah (ﷺ) prohibited two types of dress: As-Sama', and that a man sits with his legs drawn up in a garment, while there is nothing covering his private area. [Abu 'Eisa said:] There are narrations on this topic from 'Ali, Ibn 'Umar, 'Aishah, Abu Sa'eed, Jabir, and Abu Umamah. The Hadith if Abu Hurairah is a Hasan Sahih Gharib Hadith from this route. This has been reported through other routes from Abu Hurairah from the Prophet (ﷺ)}}
\hadithdefcmd{tirmidhi}{1759}{حَدَّثَنَا سُوَيْدُ بْنُ نَصْرٍ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ لَعَنَ اللَّهُ الْوَاصِلَةَ وَالْمُسْتَوْصِلَةَ وَالْوَاشِمَةَ وَالْمُسْتَوْشِمَةَ ‏"‏ ‏.‏ قَالَ نَافِعٌ الْوَشْمُ فِي اللَّثَةِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَائِشَةَ وَابْنِ مَسْعُودٍ وَأَسْمَاءَ بِنْتِ أَبِي بَكْرٍ وَابْنِ عَبَّاسٍ وَمَعْقِلِ بْنِ يَسَارٍ وَمُعَاوِيَةَ ‏.‏\hadithno{1759}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Ibn 'Umar: That the Prophet (ﷺ) said: "Allah has cursed the woman who artificially lengthens and the woman who seeks to have her hair artificially lengthened, and the woman who tattoos and the woman who seeks tattooed." Nafi' (one of the narrators) said: "Tattooing was on the gums." [Abu 'Eisa said:] This Hadith is Hasan Sahih. He said: There are narrations on this topic from Ibn Mas'ud, 'Aishah, Asma' bint Abi Bakr, Ma'qil bin Yasar, Ibn 'Abbas, and Mu'awiyah}}
\hadithdefcmd{tirmidhi}{1760}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، أَخْبَرَنَا عَلِيُّ بْنُ مُسْهِرٍ، حَدَّثَنَا أَبُو إِسْحَاقَ الشَّيْبَانِيُّ، عَنْ أَشْعَثَ بْنِ أَبِي الشَّعْثَاءِ، عَنْ مُعَاوِيَةَ بْنِ سُوَيْدِ بْنِ مُقَرِّنٍ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، قَالَ نَهَانَا رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ رُكُوبِ الْمَيَاثِرِ ‏.‏ قَالَ وَفِي الْحَدِيثِ قِصَّةٌ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَلِيٍّ وَمُعَاوِيَةَ ‏.‏ وَحَدِيثُ الْبَرَاءِ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رَوَى شُعْبَةُ عَنْ أَشْعَثَ بْنِ أَبِي الشَّعْثَاءِ نَحْوَهُ وَفِي الْحَدِيثِ قِصَّةٌ ‏.‏\hadithno{1760}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Al-Bara' bin 'Azib: "The Messenger of Allah (ﷺ) prohibited riding (while sitting on) Miyathir." [Abu 'Eisa said:] There are narrations on this topic from 'Ali and Mu'awiyah. The Hadith if Al-Bara' is Hasan Sahih. Shu'bah reported similarly from Ash'ath bin Abi Ash-Sha'tha' in the lengthy Hadith}}
\hadithdefcmd{tirmidhi}{1761}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، أَخْبَرَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ إِنَّمَا كَانَ فِرَاشُ النَّبِيِّ صلى الله عليه وسلم الَّذِي يَنَامُ عَلَيْهِ أَدَمٌ حَشْوُهُ لِيفٌ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ حَفْصَةَ وَجَابِرٍ ‏.‏\hadithno{1761}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated 'Aishah: "The only bed that the Messenger of Allah had which he slept was [made of a tanned skin] stuffed with palm-fibres." [Abu 'Eisa said:] This Hadith is Hasan Sahih. He Said: There are narrations on thus topic from Hafsah and Jabir}}
\hadithdefcmd{tirmidhi}{1762}{حَدَّثَنَا مُحَمَّدُ بْنُ حُمَيْدٍ الرَّازِيُّ، حَدَّثَنَا أَبُو تُمَيْلَةَ، وَالْفَضْلُ بْنُ مُوسَى، وَزَيْدُ بْنُ حُبَابٍ، عَنْ عَبْدِ الْمُؤْمِنِ بْنِ خَالِدٍ، عَنْ عَبْدِ اللَّهِ بْنِ بُرَيْدَةَ، عَنْ أُمِّ سَلَمَةَ، قَالَتْ كَانَ أَحَبَّ الثِّيَابِ إِلَى النَّبِيِّ صلى الله عليه وسلم الْقَمِيصُ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ إِنَّمَا نَعْرِفُهُ مِنْ حَدِيثِ عَبْدِ الْمُؤْمِنِ بْنِ خَالِدٍ تَفَرَّدَ بِهِ وَهُوَ مَرْوَزِيٌّ ‏.‏ وَرَوَى بَعْضُهُمْ هَذَا الْحَدِيثَ عَنْ أَبِي تُمَيْلَةَ عَنْ عَبْدِ الْمُؤْمِنِ بْنِ خَالِدٍ عَنْ عَبْدِ اللَّهِ بْنِ بُرَيْدَةَ عَنْ أُمِّهِ عَنْ أُمِّ سَلَمَةَ ‏.‏\hadithno{1762}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Umm Salamah: "The most loved garment to the Messenger of Allah (ﷺ) was the Qamis (long shirt)." [Abu 'Eisa said:] This Hadith is Hasan Gharib. We only know of it as a narration of 'Abdul-Mu'min bin Khalid (a narrator in the chain of this Hadith) who was alone in narrating it, and he is from Al-Marwaz. Some of them report this Hadith from Abu Tumailah, from 'Abdul-Mu'min bin Khalid, from 'Abdullah bin Buraidah, from his mother, from Umm Salamah. He said: I heard Muhammad bin Ism'ail saying: "The narration of Ibn Buraidah from his mother, from Umm Salamah is more correct, Abu Tumailah mentioned 'his mother' in it}}
\hadithdefcmd{tirmidhi}{1763}{حَدَّثَنَا زِيَادُ بْنُ أَيُّوبَ الْبَغْدَادِيُّ، حَدَّثَنَا أَبُو تُمَيْلَةَ، عَنْ عَبْدِ الْمُؤْمِنِ بْنِ خَالِدٍ، عَنْ عَبْدِ اللَّهِ بْنِ بُرَيْدَةَ، عَنْ أُمِّهِ، عَنْ أُمِّ سَلَمَةَ، قَالَتْ كَانَ أَحَبَّ الثِّيَابِ إِلَى النَّبِيِّ صلى الله عليه وسلم الْقَمِيصُ ‏.‏ قَالَ وَسَمِعْت مُحَمَّدَ بْنَ إِسْمَعِيلَ يَقُولُ حَدِيثُ عَبْدِ اللَّهِ بْنِ بُرَيْدَةَ عَنْ أُمِّهِ عَنْ أُمِّ سَلَمَةَ أَصَحُّ وَإِنَّمَا يُذْكَرُ فِيهِ أَبُو تُمَيْلَةَ عَنْ أُمِّهِ\hadithno{1763}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Umm Salamah:"The most loved garment to the Messenger of Allah (ﷺ) was the Qamis (long shirt)}}
\hadithdefcmd{tirmidhi}{1764}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، أَخْبَرَنَا الْفَضْلُ بْنُ مُوسَى، عَنْ عَبْدِ الْمُؤْمِنِ بْنِ خَالِدٍ، عَنْ عَبْدِ اللَّهِ بْنِ بُرَيْدَةَ، عَنْ أُمِّ سَلَمَةَ، قَالَتْ كَانَ أَحَبَّ الثِّيَابِ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم الْقَمِيصُ ‏.‏\hadithno{1764}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Umm Salamah:"The most loved garment to the Messenger of Allah (ﷺ) was the Qamis (long shirt)}}
\hadithdefcmd{tirmidhi}{1765}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدِ بْنِ الْحَجَّاجِ الصَّوَّافُ الْبَصْرِيُّ، حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ الدَّسْتَوَائِيُّ، حَدَّثَنِي أَبِي، عَنْ بُدَيْلِ بْنِ مَيْسَرَةَ الْعُقَيْلِيِّ، عَنْ شَهْرِ بْنِ حَوْشَبٍ، عَنْ أَسْمَاءَ بِنْتِ يَزِيدَ بْنِ السَّكَنِ الأَنْصَارِيَّةِ، قَالَتْ كَانَ كُمُّ يَدِ رَسُولِ اللَّهِ صلى الله عليه وسلم إِلَى الرُّسْغِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏\hadithno{1765}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Asma' bint Yazid bin As-Sakan Al-Ansariyyah:"The sleeves of (the shirt) of the Messenger of Allah (ﷺ) were to the wrist." [Abu 'Eisa said:] This Hadith is Hasan Gharib}}
\hadithdefcmd{tirmidhi}{1766}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، حَدَّثَنَا عَبْدُ الصَّمَدِ بْنُ عَبْدِ الْوَارِثِ، حَدَّثَنَا شُعْبَةُ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا لَبِسَ قَمِيصًا بَدَأَ بِمَيَامِنِهِ ‏.‏ قَالَ أَبُو عِيسَى وَرَوَى غَيْرُ وَاحِدٍ هَذَا الْحَدِيثَ عَنْ شُعْبَةَ بِهَذَا الإِسْنَادِ عَنْ أَبِي هُرَيْرَةَ مَوْقُوفًا وَلاَ نَعْلَمُ أَحَدًا رَفَعَهُ غَيْرَ عَبْدِ الصَّمَدِ بْنِ عَبْدِ الْوَارِثِ عَنْ شُعْبَةَ ‏.‏\hadithno{1766}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abu Hurairah: "When the Messenger of Allah (ﷺ) put on a Qamis he began with the right side. [Abu 'Eisa said:] Others have reported this Hadith from Shu'bah with this chain, but they dod narrate it in Marfu' form, only 'Abdus-Samad narrated it Marfu}}
\hadithdefcmd{tirmidhi}{1767}{\hadithno{1767}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan}\hadithtrans{}}
\hadithdefcmd{tirmidhi}{1768}{حَدَّثَنَا يُوسُفُ بْنُ عِيسَى، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا يُونُسُ بْنُ أَبِي إِسْحَاقَ، عَنِ الشَّعْبِيِّ، عَنْ عُرْوَةَ بْنِ الْمُغِيرَةِ بْنِ شُعْبَةَ، عَنْ أَبِيهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم لَبِسَ جُبَّةً رُومِيَّةً ضَيِّقَةَ الْكُمَّيْنِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1768}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated 'Urwah bin Al-Mugirah bin Shu'bah: From his father: "The Prophet (ﷺ) wore a Roman Jubbah with tight sleeves." [Abu 'Eisa said:] This Hadith is Hasan Sahih}}
\hadithdefcmd{tirmidhi}{1769}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا ابْنُ أَبِي زَائِدَةَ، عَنِ الْحَسَنِ بْنِ عَيَّاشٍ، عَنْ أَبِي إِسْحَاقَ، هُوَ الشَّيْبَانِيُّ عَنِ الشَّعْبِيِّ، قَالَ قَالَ الْمُغِيرَةُ بْنُ شُعْبَةَ أَهْدَى دِحْيَةُ الْكَلْبِيُّ لِرَسُولِ اللَّهِ صلى الله عليه وسلم خُفَّيْنِ فَلَبِسَهُمَا ‏.‏ قَالَ أَبُو عِيسَى وَقَالَ إِسْرَائِيلُ عَنْ جَابِرٍ عَنْ عَامِرٍ وَجُبَّةً فَلَبِسَهُمَا حَتَّى تَخَرَّقَا لاَ يَدْرِي النَّبِيُّ صلى الله عليه وسلم أَذَكِيٌّ هُمَا أَمْ لاَ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ أَبُو إِسْحَاقَ الَّذِي رَوَى هَذَا عَنِ الشَّعْبِيِّ هُوَ أَبُو إِسْحَاقَ الشَّيْبَانِيُّ وَاسْمُهُ سُلَيْمَانُ وَالْحَسَنُ بْنُ عَيَّاشٍ هُوَ أَخُو أَبِي بَكْرِ بْنِ عَيَّاشٍ ‏.‏\hadithno{1769}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ash-Sha'bi: From Al-Mughirah bin Shu'bah: "Dihyah Al-Kalbi gave a pair of Khuff to the Messenger of Allah (ﷺ), so he wore them." [Abu 'Eisa said:] Isra'il said: "From Jabir, from 'Amir: 'And a Jubbah, so he wore them until they tore. And the Prophet (ﷺ) did not know whether they were from a slaughtered animal or not.'" This Hadith is Hasan Gharib. Abu Ishaq, the one who reported from Ash-Sha'bi, is Abu Ishaq Ash-Shaibani, and his name is Sulaiman. Al-Hasan bin 'Ayyash is the brother of Abu Bakr bin 'Ayyash}}
\hadithdefcmd{tirmidhi}{1770}{\hadithno{1770}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan}\hadithtrans{}}
\hadithdefcmd{tirmidhi}{1771}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ يَزِيدَ الرِّشْكِ، عَنْ أَبِي الْمَلِيحِ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ نَهَى عَنْ جُلُودِ السِّبَاعِ ‏.‏ وَهَذَا أَصَحُّ ‏.‏\hadithno{1771}\hadithgrade{Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Abu Al-Malih:"The Prophet (ﷺ) prohibited predator skins." And this chain is more correct}}
\hadithdefcmd{tirmidhi}{1772}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا أَبُو دَاوُدَ، حَدَّثَنَا هَمَّامٌ، عَنْ قَتَادَةَ، قَالَ قُلْتُ لأَنَسِ بْنِ مَالِكٍ كَيْفَ كَانَ نَعْلُ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ لَهُمَا قِبَالاَنِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1772}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Narrated Qatadah:"I asked Anas bin Malik: 'How were the sandals of the Messenger of Allah (ﷺ) ? He said: 'They had two straps}}
\hadithdefcmd{tirmidhi}{1773}{حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، أَخْبَرَنَا حِبَّانُ بْنُ هِلاَلٍ، حَدَّثَنَا هَمَّامٌ، حَدَّثَنَا قَتَادَةُ، عَنْ أَنَسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ نَعْلاَهُ لَهُمَا قِبَالاَنِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ عَبَّاسٍ وَأَبِي هُرَيْرَةَ ‏.‏\hadithno{1773}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Qatadah: From Anas: "The sandals of the Prophet (ﷺ) had two straps." [Abu 'Eisa said:] This Hadith is Hasan Sahih. He said: There are narrations on this topic from Ibn 'Abbas, and Abu Hurairah}}
\hadithdefcmd{tirmidhi}{1774}{حَدَّثَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، ح وَحَدَّثَنَا الأَنْصَارِيُّ، حَدَّثَنَا مَعْنٌ، حَدَّثَنَا مَالِكٌ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَمْشِي أَحَدُكُمْ فِي نَعْلٍ وَاحِدَةٍ لِيُنْعِلْهُمَا جَمِيعًا أَوْ لِيُحْفِهِمَا جَمِيعًا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ جَابِرٍ ‏.‏\hadithno{1774}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Abu Hurairah: That the Messenger of Allah (ﷺ) said: "Do not walk in one sandal, either wear both sandals, or go barefoot." [Abu 'Eisa said:] This Hadith is Hasan Sahih. He said: There is something on this topic from Jabir}}
\hadithdefcmd{tirmidhi}{1775}{حَدَّثَنَا أَزْهَرُ بْنُ مَرْوَانَ الْبَصْرِيُّ، حَدَّثَنَا الْحَارِثُ بْنُ نَبْهَانَ، عَنْ مَعْمَرٍ، عَنْ عَمَّارِ بْنِ أَبِي عَمَّارٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يَنْتَعِلَ الرَّجُلُ وَهُوَ قَائِمٌ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ ‏.‏ وَرَوَى عُبَيْدُ اللَّهِ بْنُ عَمْرٍو الرَّقِّيُّ هَذَا الْحَدِيثَ عَنْ مَعْمَرٍ عَنْ قَتَادَةَ عَنْ أَنَسٍ وَكِلاَ الْحَدِيثَيْنِ لاَ يَصِحُّ عِنْدَ أَهْلِ الْحَدِيثِ ‏.‏ وَالْحَارِثُ بْنُ نَبْهَانَ لَيْسَ عِنْدَهُمْ بِالْحَافِظِ وَلاَ نَعْرِفُ لِحَدِيثِ قَتَادَةَ عَنْ أَنَسٍ أَصْلاً ‏.‏\hadithno{1775}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abu Hurairah: "The Messenger of Allah (ﷺ) prohibited that a man should put on sandals while he is standing." [Abu 'Eisa said:] This Hadith is Hasan Gharib. 'Ubaidullah bin 'Amr Ar-Raqqi reported this Hadith from Ma'mar, from Qatadah, from Anas. Both of the Ahadith are not correct according to the people of Hadith. Al-Harith bin Nabhan is not a Hafiz according to them, and we do not know any basis for the narration of Qatadah from Anas}}
\hadithdefcmd{tirmidhi}{1776}{حَدَّثَنَا أَبُو جَعْفَرٍ السِّمْنَانِيُّ، حَدَّثَنَا سُلَيْمَانُ بْنُ عُبَيْدِ اللَّهِ الرَّقِّيُّ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عَمْرٍو الرَّقِّيُّ، عَنْ مَعْمَرٍ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى أَنْ يَنْتَعِلَ الرَّجُلُ وَهُوَ قَائِمٌ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ ‏.‏ وَقَالَ مُحَمَّدُ بْنُ إِسْمَاعِيلَ وَلاَ يَصِحُّ هَذَا الْحَدِيثُ وَلاَ حَدِيثُ مَعْمَرٍ عَنْ عَمَّارِ بْنِ أَبِي عَمَّارٍ عَنْ أَبِي هُرَيْرَةَ ‏.‏\hadithno{1776}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Anas: "The Messenger of Allah (ﷺ) prohibited that a man should put on sandals while he is standing." [Abu 'Eisa said:] This Hadith is Gharib. Muhammad bin Isma'il said: "This Hadith is not correct, not the Hadith of Ma'mar from 'Ammar bin Abi 'Ammar, from Abu Hurairah (no)}}
\hadithdefcmd{tirmidhi}{1777}{حَدَّثَنَا الْقَاسِمُ بْنُ دِينَارٍ، حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ السَّلُولِيُّ، كُوفِيٌّ حَدَّثَنَا هُرَيْمُ بْنُ سُفْيَانَ الْبَجَلِيُّ الْكُوفِيُّ، عَنْ لَيْثٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ رُبَّمَا مَشَى النَّبِيُّ صلى الله عليه وسلم فِي نَعْلٍ وَاحِدَةٍ ‏.‏\hadithno{1777}\hadithgrade{Ahmad Muhammad Shakir: Munkar; Al-Albani: Munkar; Zubair Ali Zai: Daif}\hadithtrans{Narrated 'Aishah:"Sometimes the Prophet (ﷺ) would walk in one sandal}}
\hadithdefcmd{tirmidhi}{1778}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّهَا مَشَتْ بِنَعْلٍ وَاحِدَةٍ ‏.‏ وَهَذَا أَصَحُّ ‏.‏ قَالَ أَبُو عِيسَى وَهَكَذَا رَوَاهُ سُفْيَانُ الثَّوْرِيُّ وَغَيْرُ وَاحِدٍ عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ مَوْقُوفًا وَهَذَا أَصَحُّ ‏.‏\hadithno{1778}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated 'Abdur-Rahman bin Al-Qasim: From his father, about 'Aishah that: "She would walk in one sandal." This is more correct. [Abu 'Eisa said:] This is how it was reported by Sufyan Ath-Thawri and others, from 'Abdur-Rahman bin Al-Qasim, in Mawquf form, and this is more correct}}
\hadithdefcmd{tirmidhi}{1779}{حَدَّثَنَا الأَنْصَارِيُّ، حَدَّثَنَا مَعْنٌ، حَدَّثَنَا مَالِكٌ، ح وَحَدَّثَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا انْتَعَلَ أَحَدُكُمْ فَلْيَبْدَأْ بِالْيَمِينِ وَإِذَا نَزَعَ فَلْيَبْدَأْ بِالشِّمَالِ فَلْتَكُنِ الْيُمْنَى أَوَّلَهُمَا تُنْعَلُ وَآخِرَهُمَا تُنْزَعُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1779}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Abu Hurairah: That the Messenger of Allah (ﷺ) said: "When one of you dons sandals, then let him begin with the right. And when he removes them then let him begin with left, so that the right will be the first to put on and the last of them removed." [Abu 'Eisa said:] This Hadith is Hasan Sahih}}
\hadithdefcmd{tirmidhi}{1780}{حَدَّثَنَا يَحْيَى بْنُ مُوسَى، حَدَّثَنَا سَعِيدُ بْنُ مُحَمَّدٍ الْوَرَّاقُ، وَأَبُو يَحْيَى الْحِمَّانِيُّ قَالاَ حَدَّثَنَا صَالِحُ بْنُ حَسَّانَ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِذَا أَرَدْتِ اللُّحُوقَ بِي فَلْيَكْفِيكِ مِنَ الدُّنْيَا كَزَادِ الرَّاكِبِ وَإِيَّاكِ وَمُجَالَسَةَ الأَغْنِيَاءِ وَلاَ تَسْتَخْلِقِي ثَوْبًا حَتَّى تُرَقِّعِيهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ صَالِحِ بْنِ حَسَّانَ ‏.‏ قَالَ وَسَمِعْتُ مُحَمَّدًا يَقُولُ صَالِحُ بْنُ حَسَّانَ مُنْكَرُ الْحَدِيثِ وَصَالِحُ بْنُ أَبِي حَسَّانَ الَّذِي رَوَى عَنْهُ ابْنُ أَبِي ذِئْبٍ ثِقَةٌ ‏.‏ قَالَ أَبُو عِيسَى وَمَعْنَى قَوْلِهِ ‏"‏ وَإِيَّاكِ وَمُجَالَسَةَ الأَغْنِيَاءِ ‏"‏ ‏.‏ هُوَ نَحْوُ مَا رُوِيَ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏"‏ مَنْ رَأَى مَنْ فُضِّلَ عَلَيْهِ فِي الْخَلْقِ وَالرِّزْقِ فَلْيَنْظُرْ إِلَى مَنْ هُوَ أَسْفَلُ مِنْهُ مِمَّنْ فُضِّلَ هُوَ عَلَيْهِ فَإِنَّهُ أَجْدَرُ أَنْ لاَ يَزْدَرِيَ نِعْمَةَ اللَّهِ عَلَيْهِ ‏"‏ ‏.‏ وَيُرْوَى عَنْ عَوْنِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ قَالَ صَحِبْتُ الأَغْنِيَاءَ فَلَمْ أَرَ أَحَدًا أَكْثَرَ هَمًّا مِنِّي أَرَى دَابَّةً خَيْرًا مِنْ دَابَّتِي وَثَوْبًا خَيْرًا مِنْ ثَوْبِي وَصَحِبْتُ الْفُقَرَاءَ فَاسْتَرَحْتُ ‏.‏\hadithno{1780}\hadithgrade{Ahmad Muhammad Shakir: Very Daif; Al-Albani: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated 'Aishah: "The Messenger of Allah (ﷺ) said to me: 'If you want to stick with me, then suffice yourself in the world with the provisions of the rider. And beware of gatherings of the rich, and do not consider a garment to be worn out until it has been patched.'" [Abu 'Eisa said:] This Hadith is Gharib, we do not know of it except as a narration of Salih bin Hassan. He said: I heard Muhammad bin Isma'il saying: "Salih bin Hassan is Munkar is Hadith." And Salih bin Hassan - the one who Ibn Abi Dhi'b reports from - is trustworthy. [Abu 'Eisa said:] The meaning of this saying: "And beware of gathering of the rich" is similar to what was related from Abu Hurairah from the Prophet (ﷺ), that he said: "Whoever sees one that has been more favored than him in appearance and provision, then let him look at the one who is less than him, rather than one who is favored more than him. For indeed it is more appropriate so that he not scorn Allah's favors [upon him]." And it has been related from 'Awn bin 'Abdullah who said: "I accompanied the rich, and did not see anyone with more troubles than me. I saw a beast that was better than my beast, and a garment that was better than my garment. And I accompanied the poor, and felt at ease}}
\hadithdefcmd{tirmidhi}{1781}{\hadithno{1781}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih}\hadithtrans{}}
\hadithdefcmd{tirmidhi}{1782}{حَدَّثَنَا حُمَيْدُ بْنُ مَسْعَدَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ حُمْرَانَ، عَنْ أَبِي سَعِيدٍ، وَهُوَ عَبْدُ اللَّهِ بْنُ بُسْرٍ قَالَ سَمِعْتُ أَبَا كَبْشَةَ الأَنْمَارِيَّ، يَقُولُ كَانَتْ كِمَامُ أَصْحَابِ رَسُولِ اللَّهِ صلى الله عليه وسلم بُطْحًا ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ مُنْكَرٌ ‏.‏ وَعَبْدُ اللَّهِ بْنُ بُسْرٍ بَصْرِيٌّ هُوَ ضَعِيفٌ عِنْدَ أَهْلِ الْحَدِيثِ ضَعَّفَهُ يَحْيَى بْنُ سَعِيدٍ وَغَيْرُهُ ‏.‏ وَبُطْحٌ يَعْنِي وَاسِعَةٌ ‏.‏\hadithno{1782}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abu Sa'eed - who is 'Abdullah bin Busr: "I heard Abu Kabshah Al-Anmari saying: 'The Kimam (caps) of the Companions of the Messenger of Allah (ﷺ) were Buthan (stretched over the head).'" [Abu 'Eisa said:] This Hadith is Munkar, 'Abdullah bin Busr is from Al-Basrah, and he is weak according to the people of Hadith. Yahya bin Sa'eed and others graded him weak. Buthun means expansive}}
\hadithdefcmd{tirmidhi}{1783}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ أَبِي إِسْحَاقَ، عَنْ مُسْلِمِ بْنِ نَذِيرٍ، عَنْ حُذَيْفَةَ، قَالَ أَخَذَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِعَضَلَةِ سَاقِي أَوْ سَاقِهِ فَقَالَ ‏ "‏ هَذَا مَوْضِعُ الإِزَارِ فَإِنْ أَبَيْتَ فَأَسْفَلُ فَإِنْ أَبَيْتَ فَلاَ حَقَّ لِلإِزَارِ فِي الْكَعْبَيْنِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ رَوَاهُ الثَّوْرِيُّ وَشُعْبَةُ عَنْ أَبِي إِسْحَاقَ ‏.‏\hadithno{1783}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Hudhaifa: "The Messenger of Allah (ﷺ) took hold of the calf of my shin - or his shin - and he said: "This is the place of the Izar, if you must lower it, then the Izar has no right to be on the ankles." [Abu 'Eisa said:] This Hadith is Hasan Sahih. Ath-Thawri and Shu'bah reported it from Abu Ishaq}}
\hadithdefcmd{tirmidhi}{1784}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا مُحَمَّدُ بْنُ رَبِيعَةَ، عَنْ أَبِي الْحَسَنِ الْعَسْقَلاَنِيِّ، عَنْ أَبِي جَعْفَرِ بْنِ مُحَمَّدِ بْنِ رُكَانَةَ، عَنْ أَبِيهِ، أَنَّ رُكَانَةَ، صَارَعَ النَّبِيَّ صلى الله عليه وسلم فَصَرَعَهُ النَّبِيُّ صلى الله عليه وسلم قَالَ رُكَانَةُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنَّ فَرْقَ مَا بَيْنَنَا وَبَيْنَ الْمُشْرِكِينَ الْعَمَائِمُ عَلَى الْقَلاَنِسِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ وَإِسْنَادُهُ لَيْسَ بِالْقَائِمِ ‏.‏ وَلاَ نَعْرِفُ أَبَا الْحَسَنِ الْعَسْقَلاَنِيَّ وَلاَ ابْنَ رُكَانَةَ ‏.‏\hadithno{1784}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abu Ja'far bin Muhammad bin Rukanah: From his father that Rukanah wrestled the Prophet (ﷺ) and the Prophet (ﷺ) won the match. Rukanah said: "I heard the Messenger of Allah (ﷺ) saying: 'Indeed what distinguishes between us and between the idolater is the turban over the cap.'" [Abu 'Eisa said:] This Hadith is Hasan Gharib. Its chain is not established, and we do not know of Abu Al-Hasan Al-'Asqalani, nor Ibn Rukanah}}
\hadithdefcmd{tirmidhi}{1785}{حَدَّثَنَا مُحَمَّدُ بْنُ حُمَيْدٍ، حَدَّثَنَا زَيْدُ بْنُ حُبَابٍ، وَأَبُو تُمَيْلَةَ يَحْيَى بْنُ وَاضِحٍ عَنْ عَبْدِ اللَّهِ بْنِ مُسْلِمٍ، عَنْ عَبْدِ اللَّهِ بْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، قَالَ جَاءَ رَجُلٌ إِلَى النَّبِيِّ صلى الله عليه وسلم وَعَلَيْهِ خَاتَمٌ مِنْ حَدِيدٍ فَقَالَ ‏"‏ مَا لِي أَرَى عَلَيْكَ حِلْيَةَ أَهْلِ النَّارِ ‏"‏ ‏.‏ ثُمَّ جَاءَهُ وَعَلَيْهِ خَاتَمٌ مِنْ صُفْرٍ فَقَالَ ‏"‏ مَا لِي أَجِدُ مِنْكَ رِيحَ الأَصْنَامِ ‏"‏ ‏.‏ ثُمَّ أَتَاهُ وَعَلَيْهِ خَاتَمٌ مِنْ ذَهَبٍ فَقَالَ ‏"‏ مَا لِي أَرَى عَلَيْكَ حِلْيَةَ أَهْلِ الْجَنَّةِ ‏"‏ ‏.‏ قَالَ مِنْ أَىِّ شَيْءٍ أَتَّخِذُهُ قَالَ ‏"‏ مِنْ وَرِقٍ وَلاَ تُتِمَّهُ مِثْقَالاً ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ ‏.‏ وَفِي الْبَابِ عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو ‏.‏ وَعَبْدُ اللَّهِ بْنُ مُسْلِمٍ يُكْنَى أَبَا طَيْبَةَ وَهُوَ مَرْوَزِيٌّ ‏.‏\hadithno{1785}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Hasan}\hadithtrans{Narrated 'Abdullah bin Buraidah: From his father who said: "A man wearing an iron ring came to the Prophet (ﷺ). So he said to him: 'What is this I see on you, jewelry of the people of the Fire ?' Then he came wearing a ring of brass. So he said: 'What is this smell of idols I sense on you ?' Then he came wearing a ring of gold. So he said to him: 'What is this jewelry of the people of Paradise I see on you ?' So he said: 'What should I use then ?' He said: 'From silver, but not its entire weight." [Abu 'Eisa said:] This Hadith is Gharib and there are narrations on this topic from 'Abdullah bin 'Amr, and 'Abdullah bin Muslim's Kunyah is Abu Taibah, and he is from Al-Marwaz}}
\hadithdefcmd{tirmidhi}{1786}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، عَنْ عَاصِمِ بْنِ كُلَيْبٍ، عَنِ ابْنِ أَبِي مُوسَى، قَالَ سَمِعْتُ عَلِيًّا، يَقُولُ نَهَانِي رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الْقَسِّيِّ وَالْمِيثَرَةِ الْحَمْرَاءِ وَأَنْ أَلْبَسَ خَاتَمِي فِي هَذِهِ وَفِي هَذِهِ ‏.‏ وَأَشَارَ إِلَى السَّبَّابَةِ وَالْوُسْطَى ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَابْنُ أَبِي مُوسَى هُوَ أَبُو بُرْدَةَ بْنُ أَبِي مُوسَى وَاسْمُهُ عَامِرُ بْنُ عَبْدِ اللَّهِ بْنِ قَيْسٍ ‏.‏\hadithno{1786}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Daif; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated Ibn Abi Musa: "I heard 'Ali saying: 'The Messenger of Allah (ﷺ) prohibited Al-Qassi, the red Mitharah, and wearing rings on this and this.' And he pointed to the index and middle fingers." [Abu 'Eisa said:] This Hadith is Hasan Sahih. Ibn Abi Musa is Abu Burdah bin Abi Musa and his name is 'Amir bin 'Abdullah bin Qais}}
\hadithdefcmd{tirmidhi}{1787}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، حَدَّثَنِي أَبِي، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، قَالَ كَانَ أَحَبَّ الثِّيَابِ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم يَلْبَسُهَا الْحِبَرَةُ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ ‏.‏\hadithno{1787}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Anas: "The garment the Messenger (ﷺ) like most to wear was the Hibrah." [Abu 'Eisa said:] This Hadith is Hasan Sahih Gharib}}
